#include "stdint.h"

//--------------------------------- functions----------------------------------//
extern void ACU_Arc_check(void);
extern void ACU_Arc_check1(void);
extern void ACU_Arc_check2(void);
extern void ACU_Arc_check3(void);
extern void IDB_Arc_check(void);
extern void RCU_Arc_check(void);
extern void RWA1_Arc_check(void);
extern void RWA2_Arc_check(void);
extern void ECU_check(void);

extern void No_signal_RC(void);
