
#define __KATECH_LOGIC_C__


#include "KATECK_Logic.h"
#include "can.h"
#include "define.h"
#include "Global_Variable.h"
#include "board.h"

#include "Logic/ADM_Integrated_Logic.h"
#include "Logic/Param_Match.h"
#include "Safety_Layer/ECU_Check/ECU_Check.h"

void ECU3_KATECH_Logic_init(void)
{

}

void ECU3_KATECH_Logic_2ms(void)
{
	System_Check_Func();
/*	Input_Data_Set_Logic();
	ADM_Integrated_Logic_step();
	Output_Data_Set_Logic();*/
}

void ECU3_KATECH_Logic_5ms(void)
{
	//System_Check_Func();
}

void ECU3_KATECH_Logic_10ms(void)
{
	GV_DIN_CH1 = Digital_Read(DIN_0);
	GV_DIN_CH2 = Digital_Read(DIN_1);
	Emergency_Switch = GV_DIN_CH1;

	IDB_Arc_check();
	RCU_Arc_check();
	RWA1_Arc_check();
	RWA2_Arc_check();
	ECU_check();
}

void ECU3_KATECH_Logic_20ms(void)
{

}

void ECU3_KATECH_Logic_100ms(void)
{

}
void ECU3_KATECH_Logic_200ms(void)
{
// 아래 함수 작동 검증 필요
//	No_signal_RC();
}
void ECU3_KATECH_Logic_1000ms(void)
{

}


